pub struct EventInvalidationStrategy {
pub prefix: String,
pub default_ttl: Duration,
pub use_versioning: bool,
}Expand description
Event-based invalidation strategy
This strategy explicitly invalidates cache entries in response to specific events.
Fields
prefix: StringKey prefix to use
default_ttl: DurationDefault TTL for cache entries
use_versioning: boolWhether to use versioned keys
Implementations
Sourceimpl EventInvalidationStrategy
impl EventInvalidationStrategy
Sourcepub fn new(prefix: &str, default_ttl: Duration, use_versioning: bool) -> Self
pub fn new(prefix: &str, default_ttl: Duration, use_versioning: bool) -> Self
Create a new event-based invalidation strategy
Sourcepub async fn versioned_key(
&self,
cache: &dyn CacheService,
entity_type: &str,
) -> CacheResult<String>
pub async fn versioned_key( &self, cache: &dyn CacheService, entity_type: &str, ) -> CacheResult<String>
Generate a versioned key if versioning is enabled
Sourcepub async fn generate_key_async(
&self,
cache: &dyn CacheService,
entity_type: &str,
entity_id: &str,
) -> CacheResult<String>
pub async fn generate_key_async( &self, cache: &dyn CacheService, entity_type: &str, entity_id: &str, ) -> CacheResult<String>
Generate a key with versioning support for async contexts